@@ -11,15 +11,12 @@ class ReportCommand(CliCommand):
         self._sysinfo_api_endpoint = f"http://{config['device_address']}/api/sysinfo/v1.0"
 
     def setup_parser(self, parser):
-        pass
+        parser.add_argument('-o', '--output', help='output path of the diagnostic report', default='report.zip')
 
     def run(self, args):
-        report_name = "/tmp/report.zip"
-        if len(args) > 2:
-            if args[2] in ["-o", "--output"]:
-                report_name = args[3]
+        report_name = args.output
         if not report_name.endswith(".zip"):
             report_name += ".zip"
-        print(f"Downloading report: {report_name}")
+        print(f"Downloading report to {report_name}")
         r = requests.get(f"{self._sysinfo_api_endpoint}/report")
         open(report_name, 'wb').write(r.content)
